@@ -1,7 +1,5 @@
-#include <iostream>
+#include <algorithm>
 #include <string>
-using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -40,11 +38,11 @@ extern "C" {
     int pp = p*p;
     int n = INTEGER(n_r)[0];
 
-    string family = CHAR(STRING_ELT(family_r,0));
+    std::string family = CHAR(STRING_ELT(family_r,0));
     int *weights = INTEGER(weights_r);
 
     //priors and starting
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
 
     double *betaMu = NULL;
     double *betaSd = NULL;
@@ -235,9 +233,9 @@ extern "C" {
 	  REAL(tuning_r)[b*p+j] = tuning[j];
 	  
 	  if(accept[j]/batchLength > acceptRate){
-	    tuning[j] += min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	    tuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	  }else{
-	    tuning[j] -= min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	    tuning[j] -= std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	  }
 	  accept[j] = 0.0;
 	}
