@@ -141,9 +141,9 @@ extern "C" {
       }
       
       //construct covariance matrix
-      #pragma omp parallel 
-      {
-      #pragma omp for private(ii, k, l, h)
+      // #pragma omp parallel 
+      // {
+      // #pragma omp for private(ii, k, l, h)
       for(jj = 0; jj < n; jj++){
       	for(ii = jj; ii < n; ii++){	
       	  for(k = 0; k < m; k++){
@@ -156,11 +156,11 @@ extern "C" {
       	  }
       	}
       }
-      } //parallel for
+      // } //parallel for
 
-      #pragma omp parallel 
-      {
-      #pragma omp for private(ii, k, l, h)
+      // #pragma omp parallel 
+      // {
+      // #pragma omp for private(ii, k, l, h)
       for(jj = 0; jj < q; jj++){
       	for(ii = 0; ii < n; ii++){	
       	  for(k = 0; k < m; k++){
@@ -173,7 +173,7 @@ extern "C" {
       	  }
       	}
       }
-      } //parallel for
+      // } //parallel for
     
       F77_NAME(dpotrf)(lower, &nm, S_obs, &nm, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
       F77_NAME(dpotri)(lower, &nm, S_obs, &nm, &info); if(info != 0){error("c++ error: dpotri failed\n");}	 
