@@ -474,9 +474,9 @@ extern "C" {
 	  }
 	  
 	  //construct covariance matrix
-          #pragma omp parallel 
-	  {
-          #pragma omp for private(ii, k, l, h)
+          // #pragma omp parallel 
+	  // {
+          // #pragma omp for private(ii, k, l, h)
 	    for(jj = 0; jj < n; jj++){
 	      for(ii = jj; ii < n; ii++){	
 		for(k = 0; k < m; k++){
@@ -489,7 +489,7 @@ extern "C" {
 		}
 	      }
 	    }
-	  } //parallel for
+	  // } //parallel for
 
 	  if(nugget){
 	    if(PsiDiag){
