@@ -1,7 +1,4 @@
-#include <iostream>
 #include <string>
-using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -65,7 +62,7 @@ extern "C" {
     int nSamples = INTEGER(nSamples_r)[0];
     
     //priors
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
     double *betaMu = NULL;
     double *betaC = NULL;
     
@@ -79,7 +76,7 @@ extern "C" {
     
     bool nugget = static_cast<bool>(INTEGER(nugget_r)[0]);
     bool PsiDiag = static_cast<bool>(INTEGER(PsiDiag_r)[0]);
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
 
