@@ -300,9 +300,9 @@ extern "C" {
 	  }
 
 	  //construct covariance matrix
-          #pragma omp parallel 
-	  {
-          #pragma omp for private(ii, k, l, h)
+          // #pragma omp parallel 
+	  // {
+          // #pragma omp for private(ii, k, l, h)
 	    for(jj = 0; jj < q; jj++){
 	      for(ii = jj; ii < q; ii++){	
 		for(k = 0; k < m; k++){
@@ -315,12 +315,12 @@ extern "C" {
 		}
 	      }
 	    }
-	  } //parallel for
+	  // } //parallel for
 
 	  
-          #pragma omp parallel 
-	  {
-          #pragma omp for private(ii, k, l, h)
+          // #pragma omp parallel 
+	  // {
+          // #pragma omp for private(ii, k, l, h)
 	    for(jj = 0; jj < n; jj++){
 	      for(ii = 0; ii < q; ii++){	
 		for(k = 0; k < m; k++){
@@ -333,7 +333,7 @@ extern "C" {
 		}
 	      }
 	    }
-	  } //parallel for
+	  // } //parallel for
 	  
 	  detCand = 0.0;
 	  F77_NAME(dpotrf)(lower, &qm, K, &qm, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
@@ -426,9 +426,9 @@ extern "C" {
 	}
 	
 	//construct covariance matrix
-        #pragma omp parallel 
-	{
-        #pragma omp for private(ii, k, l, h)
+        // #pragma omp parallel 
+	// {
+        // #pragma omp for private(ii, k, l, h)
 	  for(jj = 0; jj < q; jj++){
 	    for(ii = jj; ii < q; ii++){	
 	      for(k = 0; k < m; k++){
@@ -441,11 +441,11 @@ extern "C" {
 	      }
 	    }
 	  }
-	} //parallel for
+	// } //parallel for
 		  
-        #pragma omp parallel 
-	{
-        #pragma omp for private(ii, k, l, h)
+        // #pragma omp parallel 
+	// {
+        // #pragma omp for private(ii, k, l, h)
 	  for(jj = 0; jj < n; jj++){
 	    for(ii = 0; ii < q; ii++){	
 	      for(k = 0; k < m; k++){
@@ -458,7 +458,7 @@ extern "C" {
 	      }
 	    }
 	  }
-	} //parallel for
+	// } //parallel for
 		  
 	detCand = 0.0;
 	F77_NAME(dpotrf)(lower, &qm, K, &qm, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
